@@ -9,7 +9,8 @@ from ..utils.misc import get_elem
 from ..utils.utils_nodes import NodeParams, parse_key
 
 from ..nodes.register import (interative_flirt, NMTSubjectAlign,
-                              NMTSubjectAlign2, NwarpApplyPriors)
+                              NMTSubjectAlign2, NwarpApplyPriors,
+                              IterREGBET)
 
 
 def create_iterative_register_pipe(
@@ -17,9 +18,11 @@ def create_iterative_register_pipe(
         wm_prob_file, csf_prob_file, n_iter, name="register_pipe"):
     """
     Registration of template (NMT or other) according to Regis:
+
     - The iterative FLIRT is between NMT_SS and subject's anat after a quick
     skull-stripping but the anat is more and more refined to corresponds to the
     brain
+
     - there is also a FNIRT done once, for comparison of the quality of the
     template on the subject's brain
 
@@ -128,36 +131,173 @@ def create_iterative_register_pipe(
     return register_pipe
 
 
-###############################################################################
-# multi / indiv_params
-###############################################################################
-def create_register_NMT_pipe(params_template, params={},
-                             name="register_NMT_pipe", NMT_version="1.2"):
+def create_native_iter_reg_pipe(params_template, params={},
+                                name="native_iter_reg_pipe"):
     """
-    Description: Register template to anat with the script NMT_subject_align,
-        and then apply it to tissues list_priors
+    Description: Register template to anat with the IterREGBET and \
+    apply the transfo to gm, wm and csf priors
+
+    Processing steps:
+
+    - IterREGBET (reg) compute transformation between T1 and template T1, \
+    using skull-stripped versions of T1 and template as well
+    - apply inv transfo (template -> native) using ApplyXFM \
+    (register_csf_to_nat, register_gm_to_nat, register_wm_to_nat)
+
+    Params:
+
+        - reg (see :class:`IterREGBET <macapype.nodes.register.IterREGBET>`) \
+    - also available as :ref:`indiv_params <indiv_params>`
 
     Inputs:
 
         inputnode:
-            T1: T1 file name
-            indiv_params: dict with individuals parameters for some nodes
+
+            t1_debiased_file:
+                debiased T1 file name
+
+            t1_debiased_file:
+                debiased skull stripped T1 file name
+
 
         arguments:
-            params_template: dictionary of info about template
 
-            params: dictionary of node sub-parameters (from a json file)
+            params_template:
+                dictionary of info about template
 
-            name: pipeline name (default = "register_NMT_pipe")
+            params:
+                dictionary of node sub-parameters (from a json file)
+
+            name:
+                pipeline name (default = "native_iter_reg_pipe")
+
+    Outputs:
+
+        register_csf_to_nat.out_file:
+            csf template tissue in subject space
+
+        register_gm_to_nat.out_file:
+            grey matter template tissue in subject space
+
+        register_wm_to_nat.out_file:
+            white matter template tissue in subject space
+    """
+
+    native_iter_reg_pipe = pe.Workflow(name=name)
+
+    # creating inputnode
+    inputnode = pe.Node(
+        niu.IdentityInterface(fields=['t1_debiased_file',
+                                      't1_debiased_brain_file',
+                                      'indiv_params']),
+        name='inputnode')
+
+    # Iterative registration to the INIA19 template
+    reg = NodeParams(IterREGBET(),
+                     params=parse_key(params, "reg"),
+                     name='reg')
+
+    reg.inputs.refb_file = params_template["template_brain"]
+
+    native_iter_reg_pipe.connect(inputnode, 't1_debiased_file',
+                                 reg, 'inw_file')
+    native_iter_reg_pipe.connect(inputnode, 't1_debiased_brain_file',
+                                 reg, 'inb_file')
+
+    native_iter_reg_pipe.connect(
+        inputnode, ('indiv_params', parse_key, "reg"),
+        reg, 'indiv_params')
+
+    # apply inv_transfo over the 3 tissues:
+    # gm
+    register_gm_to_nat = pe.Node(fsl.ApplyXFM(), name="register_gm_to_nat")
+    register_gm_to_nat.inputs.in_file = params_template["template_gm"]
+    register_gm_to_nat.inputs.output_type = "NIFTI"  # for SPM segment
+
+    native_iter_reg_pipe.connect(inputnode, 't1_debiased_file',
+                                 register_gm_to_nat, 'reference')
+    native_iter_reg_pipe.connect(reg, 'inv_transfo_file',
+                                 register_gm_to_nat, "in_matrix_file")
+
+    # wm
+    register_wm_to_nat = pe.Node(fsl.ApplyXFM(), name="register_wm_to_nat")
+    register_wm_to_nat.inputs.in_file = params_template["template_wm"]
+    register_wm_to_nat.inputs.output_type = "NIFTI"  # for SPM segment
+
+    native_iter_reg_pipe.connect(inputnode, 't1_debiased_file',
+                                 register_wm_to_nat, 'reference')
+    native_iter_reg_pipe.connect(reg, 'inv_transfo_file',
+                                 register_wm_to_nat, "in_matrix_file")
+
+    # csf
+    register_csf_to_nat = pe.Node(fsl.ApplyXFM(), name="register_csf_to_nat")
+    register_csf_to_nat.inputs.in_file = params_template["template_csf"]
+    register_csf_to_nat.inputs.output_type = "NIFTI"  # for SPM segment
+
+    native_iter_reg_pipe.connect(inputnode, 't1_debiased_file',
+                                 register_csf_to_nat, 'reference')
+    native_iter_reg_pipe.connect(reg, 'inv_transfo_file',
+                                 register_csf_to_nat, "in_matrix_file")
+
+    return native_iter_reg_pipe
+
+
+###############################################################################
+def create_register_NMT_pipe(params_template, params={},
+                             name="register_NMT_pipe", NMT_version="v1.2"):
+    """Description: Register template to anat with the script NMT_subject_align
+
+    Processing steps:
+
+    - Bias correction (norm_intensity)
+    - Deoblique (Refit with deoblique option)
+    - NMT_subject_align (see :class:`NMTSubjectAlign \
+    <macapype.nodes.register.NMTSubjectAlign>` and :class:`NMTSubjectAlign2 \
+    <macapype.nodes.register.NMTSubjectAlign2>` for explanations)
+    - apply it to tissues list_priors (NwarpApplyPriors and Allineate)
+
+    Params:
+        - norm_intensity (see `N4BiasFieldCorrection <https://\
+        nipype.readthedocs.io/en/0.12.1/interfaces/generated/nipype.interfaces\
+        .ants.segmentation.html#n4biasfieldcorrection>`_ for arguments)) - \
+        also available as :ref:`indiv_params <indiv_params>`
+        - NMT_version (default = 1.2; 1.3 is also accepted)
+
+    Inputs:
+
+        inputnode:
+
+            T1:
+                T1 file name
+
+            indiv_params:
+                dict with individuals parameters for some nodes
+
+        arguments:
+
+            params_template:
+                dictionary of info about template
+
+            params:
+                dictionary of node sub-parameters (from a json file)
+
+            name:
+                pipeline name (default = "register_NMT_pipe")
+
+            NMT_version:
+                NMT version (default = 1.2); can be overwritten in params json
 
     Outputs:
 
         norm_intensity.output_image:
             filled mask after erode
+
         align_seg_csf.out_file:
             csf template tissue in subject space
+
         align_seg_gm.out_file:
             grey matter template tissue in subject space
+
         align_seg_wm.out_file:
             white matter template tissue in subject space
     """
@@ -185,20 +325,16 @@ def create_register_NMT_pipe(params_template, params={},
     register_NMT_pipe.connect(norm_intensity, 'output_image',
                               deoblique, "in_file")
 
-    if "NMT_version" in params.keys():
-        NMT_version = params["NMT_version"]
-
     print("*** Found NMT_version {}".format(NMT_version))
 
-    if NMT_version == "1.2":
+    if NMT_version == "v1.2":
         # align subj to nmt
         NMT_subject_align = pe.Node(NMTSubjectAlign(),
                                     name='NMT_subject_align')
-    elif NMT_version == "1.3":
+    elif NMT_version == "v1.3" or NMT_version == "v2.0":
         # align subj to nmt
         NMT_subject_align = pe.Node(NMTSubjectAlign2(),
                                     name='NMT_subject_align')
-
     else:
         print("NMT_version {} is not implemented".format(NMT_version))
         exit()
@@ -208,12 +344,21 @@ def create_register_NMT_pipe(params_template, params={},
     register_NMT_pipe.connect(deoblique, 'out_file',
                               NMT_subject_align, "T1_file")
 
-    # align_masks
-    # "overwrap" of NwarpApply, with specifying the outputs as wished
-    list_priors = [params_template["template_head"],
-                   params_template["template_csf"],
-                   params_template["template_gm"],
-                   params_template["template_wm"]]
+    if NMT_version.split(".")[0] == "v1":
+
+        # align_masks
+        # "overwrap" of NwarpApply, with specifying the outputs as wished
+        list_priors = [params_template["template_head"],
+                       params_template["template_csf"],
+                       params_template["template_gm"],
+                       params_template["template_wm"]]
+
+    elif NMT_version.split(".")[0] == "v2":
+
+        # align_masks
+        # "overwrap" of NwarpApply, with specifying the outputs as wished
+        list_priors = [params_template["template_head"],
+                       params_template["template_seg"]]
 
     align_masks = pe.Node(NwarpApplyPriors(), name='align_masks2')
     align_masks.inputs.in_file = list_priors
@@ -240,46 +385,65 @@ def create_register_NMT_pipe(params_template, params={},
     register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
                               align_NMT, "in_matrix")  # -1Dmatrix_apply
 
-    # seg_csf
-    align_seg_csf = pe.Node(
-        afni.Allineate(), name="align_seg_csf", iterfield=['in_file'])
-    align_seg_csf.inputs.final_interpolation = "nearestneighbour"
-    align_seg_csf.inputs.overwrite = True
-    align_seg_csf.inputs.outputtype = "NIFTI_GZ"
+    if NMT_version.split(".")[0] == "v1":
 
-    register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 1),
-                              align_seg_csf, "in_file")  # -source
-    register_NMT_pipe.connect(norm_intensity, 'output_image',
-                              align_seg_csf, "reference")  # -base
-    register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
-                              align_seg_csf, "in_matrix")  # -1Dmatrix_apply
+        # seg_csf
+        align_seg_csf = pe.Node(
+            afni.Allineate(), name="align_seg_csf", iterfield=['in_file'])
+        align_seg_csf.inputs.final_interpolation = "nearestneighbour"
+        align_seg_csf.inputs.overwrite = True
+        align_seg_csf.inputs.outputtype = "NIFTI_GZ"
 
-    # seg_gm
-    align_seg_gm = pe.Node(
-        afni.Allineate(), name="align_seg_gm", iterfield=['in_file'])
-    align_seg_gm.inputs.final_interpolation = "nearestneighbour"
-    align_seg_gm.inputs.overwrite = True
-    align_seg_gm.inputs.outputtype = "NIFTI_GZ"
+        register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 1),
+                                  align_seg_csf, "in_file")  # -source
+        register_NMT_pipe.connect(norm_intensity, 'output_image',
+                                  align_seg_csf, "reference")  # -base
+        register_NMT_pipe.connect(
+            NMT_subject_align, 'inv_transfo_file', align_seg_csf,
+            "in_matrix")  # -1Dmatrix_apply
 
-    register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 2),
-                              align_seg_gm, "in_file")  # -source
-    register_NMT_pipe.connect(norm_intensity, 'output_image',
-                              align_seg_gm, "reference")  # -base
-    register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
-                              align_seg_gm, "in_matrix")  # -1Dmatrix_apply
+        # seg_gm
+        align_seg_gm = pe.Node(
+            afni.Allineate(), name="align_seg_gm", iterfield=['in_file'])
+        align_seg_gm.inputs.final_interpolation = "nearestneighbour"
+        align_seg_gm.inputs.overwrite = True
+        align_seg_gm.inputs.outputtype = "NIFTI_GZ"
 
-    # seg_wm
-    align_seg_wm = pe.Node(afni.Allineate(), name="align_seg_wm",
-                           iterfield=['in_file'])
-    align_seg_wm.inputs.final_interpolation = "nearestneighbour"
-    align_seg_wm.inputs.overwrite = True
-    align_seg_wm.inputs.outputtype = "NIFTI_GZ"
+        register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 2),
+                                  align_seg_gm, "in_file")  # -source
+        register_NMT_pipe.connect(norm_intensity, 'output_image',
+                                  align_seg_gm, "reference")  # -base
+        register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
+                                  align_seg_gm, "in_matrix")  # -1Dmatrix_apply
 
-    register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 3),
-                              align_seg_wm, "in_file")  # -source
-    register_NMT_pipe.connect(norm_intensity, 'output_image',
-                              align_seg_wm, "reference")  # -base
-    register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
-                              align_seg_wm, "in_matrix")  # -1Dmatrix_apply
+        # seg_wm
+        align_seg_wm = pe.Node(afni.Allineate(), name="align_seg_wm",
+                               iterfield=['in_file'])
+        align_seg_wm.inputs.final_interpolation = "nearestneighbour"
+        align_seg_wm.inputs.overwrite = True
+        align_seg_wm.inputs.outputtype = "NIFTI_GZ"
+
+        register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 3),
+                                  align_seg_wm, "in_file")  # -source
+        register_NMT_pipe.connect(norm_intensity, 'output_image',
+                                  align_seg_wm, "reference")  # -base
+        register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
+                                  align_seg_wm, "in_matrix")  # -1Dmatrix_apply
+
+    elif NMT_version.split(".")[0] == "v2":
+
+        # seg
+        align_seg = pe.Node(
+            afni.Allineate(), name="align_seg", iterfield=['in_file'])
+        align_seg.inputs.final_interpolation = "nearestneighbour"
+        align_seg.inputs.overwrite = True
+        align_seg.inputs.outputtype = "NIFTI_GZ"
+
+        register_NMT_pipe.connect(align_masks, ('out_file', get_elem, 1),
+                                  align_seg, "in_file")  # -source
+        register_NMT_pipe.connect(norm_intensity, 'output_image',
+                                  align_seg, "reference")  # -base
+        register_NMT_pipe.connect(NMT_subject_align, 'inv_transfo_file',
+                                  align_seg, "in_matrix")  # -1Dmatrix_apply
 
     return register_NMT_pipe
